pub struct GmailCodeConfig {
pub access_token: String,
pub base_url: String,
pub user_id: String,
pub user_agent: Option<String>,
pub connect_timeout: Duration,
pub request_timeout: Duration,
}Expand description
Configuration for authorized Gmail API requests.
Fields
access_token: StringGmail API OAuth access token for a mailbox controlled by the caller.
base_url: StringGmail API base URL. Keep the default for production use.
user_id: StringGmail userId path segment. me is the normal value for OAuth callers.
user_agent: Option<String>HTTP user agent sent by this client.
connect_timeout: DurationTCP connect timeout.
request_timeout: DurationTotal request timeout.
Implementations
Sourceimpl GmailCodeConfig
impl GmailCodeConfig
Sourcepub fn builder(access_token: impl Into<String>) -> GmailCodeConfigBuilder
pub fn builder(access_token: impl Into<String>) -> GmailCodeConfigBuilder
Starts a config builder with the required Gmail OAuth access token.